@@ -308,6 +308,7 @@ AttributeTableEntry attributeTable[] = {
     { "CurrentMetaMode",            NV_CTRL_STRING_CURRENT_METAMODE_VERSION_2, S|N, "Controls the current MetaMode." },
     { "XineramaInfoOrder",          NV_CTRL_STRING_NVIDIA_XINERAMA_INFO_ORDER, S|N, "Controls the nvidiaXineramaInfoOrder." },
     { "RandROutputID",              NV_CTRL_DISPLAY_RANDR_OUTPUT_ID,       N,     "The RandR Output ID that corresponds to the display device." },
+    { "Hdmi3D",                     NV_CTRL_DPY_HDMI_3D,                   N,     "Returns whether the specified display device is currently using HDMI 3D Frame Packed Stereo mode. If so, the result of refresh rate queries will be doubled." },
 
     /* TV */
     { "TVOverScan",      NV_CTRL_TV_OVERSCAN,       0, "Adjusts the amount of overscan on the specified display device." },
@@ -370,7 +371,7 @@ AttributeTableEntry attributeTable[] = {
  * about.
  */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_USED_DEDICATED_GPU_MEMORY
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_DPY_HDMI_3D
 #warning "Have you forgotten to add a new integer attribute to attributeTable?"
 #endif
 
@@ -458,6 +459,38 @@ TargetTypeEntry targetTypeTable[] = {
     { NULL, NULL, 0, 0, 0, 0, 0, 0 },
 };
 
+TargetTypeEntry *nv_get_target_type_entry_by_nvctrl(int nvctrl)
+{
+    TargetTypeEntry *targetTypeEntry;
+
+    for (targetTypeEntry = targetTypeTable;
+         targetTypeEntry->name;
+         targetTypeEntry++) {
+
+        if (targetTypeEntry->nvctrl == nvctrl) {
+            return targetTypeEntry;
+        }
+    }
+
+    return NULL;
+}
+
+TargetTypeEntry *nv_get_target_type_entry_by_name(const char *name)
+{
+    TargetTypeEntry *targetTypeEntry;
+
+    for (targetTypeEntry = targetTypeTable;
+         targetTypeEntry->name;
+         targetTypeEntry++) {
+
+        if (nv_strcasecmp(targetTypeEntry->parsed_name, name)) {
+            return targetTypeEntry;
+        }
+    }
+
+    return NULL;
+}
+
 
 
 /*
@@ -683,8 +716,9 @@ static int nv_parse_display_and_target(char *start,
                                        char *end, /* exclusive */
                                        ParsedAttribute *a)
 {
-    int digits_only, i, target_type, target_id, len;
+    int digits_only, target_id, len;
     char *tmp, *s, *pOpen, *pClose, *colon;
+    TargetTypeEntry *targetTypeEntry;
 
     /*
      * are all characters numeric? compute the target_id integer as we
@@ -761,24 +795,18 @@ static int nv_parse_display_and_target(char *start,
          */
 
         *colon = '\0';
-        target_type = -1;
 
-        for (i = 0; targetTypeTable[i].name; i++) {
-            if (nv_strcasecmp(tmp, targetTypeTable[i].parsed_name)) {
-                target_type = targetTypeTable[i].nvctrl;
-                break;
-            }
-        }
-        
+        targetTypeEntry = nv_get_target_type_entry_by_name(tmp);
+
         *colon = ':';
-        
+
         /* if we did not find a matching target name, give up */
-        
-        if (target_type == -1) {
+
+        if (!targetTypeEntry) {
             free(tmp);
             return NV_PARSER_STATUS_TARGET_SPEC_BAD_TARGET;
         }
-        
+
         /*
          * check that we have something between the colon and the end
          * of the temp string
@@ -810,7 +838,7 @@ static int nv_parse_display_and_target(char *start,
          * this is a target type-specific name.
          */
 
-        a->target_type = target_type;
+        a->target_type = targetTypeEntry->nvctrl;
 
         if (digits_only) {
             a->target_id = target_id;
